Struct alrulab_core::string::FromUtf8Error

source ·
pub struct FromUtf8Error<const N: usize> { /* private fields */ }
Wir definieren hier ein paar Fehlertypen, die beim Utf8 Konvertieren auftauchen koennen.

Wir machen in der ganzen crate im grunde die selbe implementierung wie in der std crate, nur ohne die funktionen die sowohl nicht im heapless vec als auch dynamische speicherverwaltung benoetigt.

Implementations

source

impl<const N: usize> FromUtf8Error<N>

source

pub fn as_bytes(&self) -> &[u8]

Gibt die bytes des Fehlers zurck

let str = FromUtf8Error { bytes: Vec::new(), error: Utf8Error::new() };
str.as_bytes();
source

pub fn into_bytes(self) -> Vec<u8, N>

Konvertiere den Fehler in einen Vektor

let str = FromUtf8Error { bytes: Vec::new(), error: Utf8Error::new() };
let bytes = str.into_bytes();
source

pub fn utf8_error(&self) -> Utf8Error

Gibt den Utf8 Error zurck

let str = FromUtf8Error { bytes: Vec::new(), error: Utf8Error::new() };
let error = str.utf8_error();