Struct alrulab_core::string::FromUtf8Error
source · pub struct FromUtf8Error<const N: usize> { /* private fields */ }Expand description
Wir definieren hier ein paar Fehlertypen, die beim Utf8 Konvertieren auftauchen koennen.
Wir machen in der ganzen crate im grunde die selbe implementierung wie in der std crate, nur ohne die funktionen die sowohl nicht im heapless vec als auch dynamische speicherverwaltung benoetigt.
Implementations
sourceimpl<const N: usize> FromUtf8Error<N>
impl<const N: usize> FromUtf8Error<N>
sourcepub fn as_bytes(&self) -> &[u8]
pub fn as_bytes(&self) -> &[u8]
Gibt die bytes des Fehlers zurck
let str = FromUtf8Error { bytes: Vec::new(), error: Utf8Error::new() };
str.as_bytes();sourcepub fn into_bytes(self) -> Vec<u8, N>
pub fn into_bytes(self) -> Vec<u8, N>
Konvertiere den Fehler in einen Vektor
let str = FromUtf8Error { bytes: Vec::new(), error: Utf8Error::new() };
let bytes = str.into_bytes();sourcepub fn utf8_error(&self) -> Utf8Error
pub fn utf8_error(&self) -> Utf8Error
Gibt den Utf8 Error zurck
let str = FromUtf8Error { bytes: Vec::new(), error: Utf8Error::new() };
let error = str.utf8_error();Trait Implementations
sourceimpl<const N: usize> Debug for FromUtf8Error<N>
impl<const N: usize> Debug for FromUtf8Error<N>
sourceimpl<const N: usize> Display for FromUtf8Error<N>
impl<const N: usize> Display for FromUtf8Error<N>
Repraesentiert einen Fehler, der beim Konvertieren eines Utf8 Strings in einen String
let str = FromUtf8Error { bytes: Vec::new(), error: Utf8Error::new() };
write!("{}", str);sourceimpl<const N: usize> Error for FromUtf8Error<N>
impl<const N: usize> Error for FromUtf8Error<N>
sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
1.30.0 · sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
The lower-level source of this error, if any. Read more
sourceimpl<const N: usize> PartialEq for FromUtf8Error<N>
impl<const N: usize> PartialEq for FromUtf8Error<N>
sourcefn eq(&self, other: &FromUtf8Error<N>) -> bool
fn eq(&self, other: &FromUtf8Error<N>) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl<const N: usize> Eq for FromUtf8Error<N>
impl<const N: usize> StructuralPartialEq for FromUtf8Error<N>